## Pushing Results

1. Create accounts:
   - [GitLab Account](https://transfer.hft-stuttgart.de/gitlab) (HFT Transfer)
   - [DockerHub Account](https://hub.docker.com/)

2. Add your accounts to the necessary groups in GitLab.

3. Create a Gitlab Access Token
   To authenticate with GitLab, you will need to create a **Personal Access Token**. Follow these steps:

   1. Log in to your GitLab account.
   2. Navigate to the **User Settings** by clicking on your profile icon in the top-right corner.
   3. Under **Access Tokens**, create a new token:
      - **Name**: Choose a descriptive name (e.g., `GitLab Access Token`).
      - **Scopes**: Select the appropriate scopes. For typical git operations, you will need:
        - `api`
        - `read_repository`
        - `write_repository`
      - **Expiration Date**: Set an expiration date (optional but recommended).
   4. Click **Create Access Token** and save it securely. **This is the only time the token will be shown**.

4. Configure Git to Use the Access Token
Now that you have the access token, configure git to use it for authentication. Open a terminal and follow these steps:

   1. **Cache Git Credentials** (to avoid entering the token multiple times):
      ```bash
      git config --global credential.helper cache
      ```
      This will cache your credentials for a short period of time.

   2. **Set your Git Username**:
   ```bash
   git config --global user.name "<your_name>"
   ```
   Replace `<your_name>` with your GitLab username.

   3. **Set your Git Email**:
   ```bash
   git config --global user.email "<your_email>"
   ```
   Replace `<your_email>` with the email associated with your GitLab account.

   4. **Verify the Git Configuration**:
   To check the configuration settings you just applied, use:
   ```bash
   git config -l
   ```
   This command will list all the global configurations for git.

5. **Use the Access Token** for Git Operations:
   When you perform a git operation (such as `git clone`, `git pull`, or `git push`) that requires authentication, Git will prompt you for a username and password. Use the following:
   - **Username**: Your GitLab username or email.
   - **Password**: Paste the Personal Access Token you created earlier.

   Git will then authenticate using the access token.


3. Push your results:
   - Always pull before pushing:
     ```bash
     git pull
     ```
   - In case of conflicts:
     ```bash
     git merge
     ```
   - Push your changes:
     ```bash
     git push
     ```
   - Push the Docker image:
     ```bash
     docker push <image>
     ```
