# CoTA Documentation Repository

This repository contains the complete codebase and documentation for the **CoTA Application**, an integrated moodle plugin to automate coding assignments. It is structured into backend, frontend, infrastructure, and examples components. Below, you’ll find detailed instructions on how to set up, run, and use the application.

## Table of Contents

- [CoTA Documentation Repository](#cota-documentation-repository)
  - [Table of Contents](#table-of-contents)
  - [Project Structure](#project-structure)
  - [Running the Application](#running-the-application)
  - [Application Components](#application-components)
    - [1. Backend (`cota-backend`)](#1-backend-cota-backend)
    - [2. Frontend (`cota-frontend`)](#2-frontend-cota-frontend)
    - [3. Infrastructure (`cota-infra`)](#3-infrastructure-cota-infra)
    - [4. Examples (`cota-examples`)](#4-examples-cota-examples)

---

## Project Structure

```plaintext
cota-doc/
├── cota-backend/       # Backend service documentation
├── cota-frontend/      # Frontend application documentation
├── cota-infra/         # Infrastructure and deployment configuration
├── cota-examples/      # Example implementations and usage guides
├── img/                # Images and assets for documentation
├── Installation-and-set-up/ # Guides for installation and setup
├── step_by_step_installation_guide.md # Detailed installation steps
└── README.md           # This file
```

---

## Running the Application

To start the application:

1. **Prepare the Environment**:
   ```bash
   mkdir ~/cota
   cp -R ~/dev/dtabackend/ifc/generic-proxy/ ~/cota
   sudo mkdir /tmp/dta-tests
   sudo chown root:docker /tmp/dta-tests
   export EGID=$(getent group docker | cut -d: -f3)
   ```

2. **Start the Services**:
   Navigate to the root directory and run:
   ```bash
   cd ~/cota
   docker-compose up -d
   ```

3. **Verify Running Containers**:
   Confirm all services are running:
   ```bash
   docker container ls
   ```

For more information, see [Installation and Set Up](Installation-and-set-up/).

---

## Application Components

### 1. Backend (`cota-backend`)
- Implements APIs and core logic.
- Technologies: [Java]

### 2. Frontend (`cota-frontend`)
- User interface for interacting with the application.
- Technologies: [PHP]

### 3. Infrastructure (`cota-infra`)
- Deployment and infrastructure configuration.
- Technologies: [Docker]

### 4. Examples (`cota-examples`)
- Sample implementations and usage scenarios.

---
